@@ -1,4 +1,6 @@
+import mimetypes
 import os
+import uuid
 from abc import abstractmethod, ABC
 from typing import Optional
 
@@ -46,11 +48,26 @@ class Depot(ABC):
         self._err = DepotError(err, back_num=1)
         return None
 
-    @staticmethod
-    def _get_mime_type(content):
+    def _get_mime_type(self, content):
         """
         识别文件的 mime type
         :param content:
         :return:
         """
         return magic.Magic(mime=True, uncompress=True).from_buffer(content)
+
+    def _random_file_name(self, content):
+        """
+        获取随机的文件名, 会自动识别文件后缀
+        :param content:
+        :return:
+        """
+        mime_type = self._get_mime_type(content)
+        # todo 系统的 mimetypes 识别度并不高, 很多类型都无法正常识别.
+        #  后面若找到更好的, 替换掉. 若实际使用中喷到问题了, 自己维护转换 map
+        suffix = mimetypes.guess_extension(mime_type)
+        if not suffix:
+            return self._set_error(f'parse mimetype error. mime_type: {mime_type}, suffix: {suffix}')
+        if suffix == '.jpe':  # image/jpeg 类型会返回此后缀
+            suffix = '.jpg'
+        return str(uuid.uuid4()) + suffix
